# PKVENV

Package venv

# Install

```
# pip install pkvenv
```

# Usage


```
pkvenv project_dir
```

# Config

pkvenv.json

```
{
    "name": "Application Name",
    "args": "app.py",
    "venv": "./venv",
    "include" : [
        "app.py",
        "index.html"
    ]
}

```